@@ -442,9 +442,7 @@ pub enum Key {
 	ButtonToolLens = sys::BTN_TOOL_LENS as _,
 	/// Five fingers on trackpad
 	ButtonToolQuintTap = sys::BTN_TOOL_QUINTTAP as _,
-
-	Unknown149,
-
+	ButtonStylus3 = sys::BTN_STYLUS3 as _,
 	ButtonTouch = sys::BTN_TOUCH as _,
 	ButtonStylus = sys::BTN_STYLUS as _,
 	ButtonStylus2 = sys::BTN_STYLUS2 as _,
@@ -495,10 +493,10 @@ pub enum Key {
 	Title = sys::KEY_TITLE as _,
 	Subtitle = sys::KEY_SUBTITLE as _,
 	Angle = sys::KEY_ANGLE as _,
-	Zoom = sys::KEY_ZOOM as _,
+	FullScreen = sys::KEY_FULL_SCREEN as _,
 	Mode = sys::KEY_MODE as _,
 	Keyboard = sys::KEY_KEYBOARD as _,
-	Screen = sys::KEY_SCREEN as _,
+	AspectRatio = sys::KEY_ASPECT_RATIO as _,
 	/// Media Select Computer
 	PC = sys::KEY_PC as _,
 	/// Media Select TV
@@ -751,8 +749,8 @@ pub enum Key {
 
 	/// Ambient light sensor
 	AlsToggle = sys::KEY_ALS_TOGGLE as _,
+	RotateLockToggle = sys::KEY_ROTATE_LOCK_TOGGLE as _,
 
-	Unknown231,
 	Unknown232,
 	Unknown233,
 	Unknown234,
@@ -782,9 +780,9 @@ pub enum Key {
 	Screensaver = sys::KEY_SCREENSAVER as _,
 	/// Listening Voice Command
 	Voicecommand = sys::KEY_VOICECOMMAND as _,
+	Assistant = sys::KEY_ASSISTANT as _,
+	KbdLayoutNext = sys::KEY_KBD_LAYOUT_NEXT as _,
 
-	Unknown247,
-	Unknown248,
 	Unknown249,
 	Unknown24A,
 	Unknown24B,
@@ -853,9 +851,9 @@ pub enum Key {
 
 	Data = sys::KEY_DATA as _,
 	OnscreenKeyboard = sys::KEY_ONSCREEN_KEYBOARD as _,
+	PrivacyScreenToggle = sys::KEY_PRIVACY_SCREEN_TOGGLE as _,
+	SelectiveScreenshot = sys::KEY_SELECTIVE_SCREENSHOT as _,
 
-	Unknown279,
-	Unknown27A,
 	Unknown27B,
 	Unknown27C,
 	Unknown27D,
@@ -879,58 +877,60 @@ pub enum Key {
 	Unknown28E,
 	Unknown28F,
 
-	Unknown290,
-	Unknown291,
-	Unknown292,
-	Unknown293,
-	Unknown294,
-	Unknown295,
-	Unknown296,
-	Unknown297,
-	Unknown298,
-	Unknown299,
-	Unknown29A,
-	Unknown29B,
-	Unknown29C,
-	Unknown29D,
-	Unknown29E,
-	Unknown29F,
+	Macro1 = sys::KEY_MACRO1 as _,
+	Macro2 = sys::KEY_MACRO2 as _,
+	Macro3 = sys::KEY_MACRO3 as _,
+	Macro4 = sys::KEY_MACRO4 as _,
+	Macro5 = sys::KEY_MACRO5 as _,
+	Macro6 = sys::KEY_MACRO6 as _,
+	Macro7 = sys::KEY_MACRO7 as _,
+	Macro8 = sys::KEY_MACRO8 as _,
+	Macro9 = sys::KEY_MACRO9 as _,
+	Macro10 = sys::KEY_MACRO10 as _,
+	Macro11 = sys::KEY_MACRO11 as _,
+	Macro12 = sys::KEY_MACRO12 as _,
+	Macro13 = sys::KEY_MACRO13 as _,
+	Macro14 = sys::KEY_MACRO14 as _,
+	Macro15 = sys::KEY_MACRO15 as _,
+	Macro16 = sys::KEY_MACRO16 as _,
+	Macro17 = sys::KEY_MACRO17 as _,
+	Macro18 = sys::KEY_MACRO18 as _,
+	Macro19 = sys::KEY_MACRO19 as _,
+	Macro20 = sys::KEY_MACRO20 as _,
+	Macro21 = sys::KEY_MACRO21 as _,
+	Macro22 = sys::KEY_MACRO22 as _,
+	Macro23 = sys::KEY_MACRO23 as _,
+	Macro24 = sys::KEY_MACRO24 as _,
+	Macro25 = sys::KEY_MACRO25 as _,
+	Macro26 = sys::KEY_MACRO26 as _,
+	Macro27 = sys::KEY_MACRO27 as _,
+	Macro28 = sys::KEY_MACRO28 as _,
+	Macro29 = sys::KEY_MACRO29 as _,
+	Macro30 = sys::KEY_MACRO30 as _,
 
-	Unknown2A0,
-	Unknown2A1,
-	Unknown2A2,
-	Unknown2A3,
-	Unknown2A4,
-	Unknown2A5,
-	Unknown2A6,
-	Unknown2A7,
-	Unknown2A8,
-	Unknown2A9,
-	Unknown2AA,
-	Unknown2AB,
-	Unknown2AC,
-	Unknown2AD,
 	Unknown2AE,
 	Unknown2AF,
 
-	Unknown2B0,
-	Unknown2B1,
-	Unknown2B2,
-	Unknown2B3,
-	Unknown2B4,
-	Unknown2B5,
+	MacroRecordStart = sys::KEY_MACRO_RECORD_START as _,
+	MacroRecordStop = sys::KEY_MACRO_RECORD_STOP as _,
+	MacroPresetCycle = sys::KEY_MACRO_PRESET_CYCLE as _,
+	MacroPreset1 = sys::KEY_MACRO_PRESET1 as _,
+	MacroPreset2 = sys::KEY_MACRO_PRESET2 as _,
+	MacroPreset3 = sys::KEY_MACRO_PRESET3 as _,
+
 	Unknown2B6,
 	Unknown2B7,
-	Unknown2B8,
-	Unknown2B9,
-	Unknown2BA,
-	Unknown2BB,
-	Unknown2BC,
+
+	KbdLcdMenu1 = sys::KEY_KBD_LCD_MENU1 as _,
+	KbdLcdMenu2 = sys::KEY_KBD_LCD_MENU2 as _,
+	KbdLcdMenu3 = sys::KEY_KBD_LCD_MENU3 as _,
+	KbdLcdMenu4 = sys::KEY_KBD_LCD_MENU4 as _,
+	KbdLcdMenu5 = sys::KEY_KBD_LCD_MENU5 as _,
+
 	Unknown2BD,
 	Unknown2BE,
 	Unknown2BF,
 
-	//ButtonTriggerHappy = sys::BTN_TRIGGER_HAPPY as _,
 	ButtonTriggerHappy1 = sys::BTN_TRIGGER_HAPPY1 as _,
 	ButtonTriggerHappy2 = sys::BTN_TRIGGER_HAPPY2 as _,
 	ButtonTriggerHappy3 = sys::BTN_TRIGGER_HAPPY3 as _,
